<div align="center">
    <h1>Diskord</h1>
    <img src="https://pepy.tech/badge/diskord">
    <img src="https://canary.discord.com/api/guilds/887217168276656188/embed.png">
    <img src="https://readthedocs.org/projects/diskord/badge">
    <hr>
    <sup>This library is a maintained fork of now archived library, <a href="https://github.com/Rapptz/discord.py">discord.py</a>.</sup>
    <p>
        A modern and easy to use API wrapper around Discord API written in Python.
    </p>
</div>

## Features
* Modern, Pythonic API based on `async` / `await`
* Consistent, object oriented & easy to use interface
* Provides full coverage of Discord API
* Proper and sane ratelimit handling
* Optimized in both speed and memory
* Extensions support & prebuilt powerful commands handler


## Installation

**Python 3.8 or higher** is required to install this library.

### Basic Installation
To install the library **without** full voice support, you can just run the following command:
```sh
python -m pip install diskord
```

### Voice Support
Optionally, To interact with discord's voice API, You would require voice support of this library which you can install like so:
```sh
python -m pip install diskord[voice]
```

### Development Version
You must have git installed to install development version. Otherwise, you can download the code.
```sh
$ git clone https://github.com/nerdguyahmad/diskord
$ cd diskord
$ python -m pip install -U .[voice]
```
or in short;
```sh
python -m pip install git+https://github.com/diskord-dev/diskord.git
```

## Quick Example
Here are some quick examples to give you a quickstart and show off the basic features of the library.

### Application (Slash) Commands
```py
import diskord

client = diskord.Client()

@client.slash_command(description='Ping-Pong!')
async def ping(ctx):
    await ctx.respond('Pong!')

client.run('token')
```

### Legacy (Prefixed) Commands
```py
import diskord
from diskord.ext import commands

bot = commands.Bot(command_prefix='>')

@bot.command()
async def ping(ctx):
    await ctx.send('pong')

bot.run('token')
```
You can find more examples in the [`examples`](examples/) directory.

## Links
* [Latest Documentation](https://diskord.readthedocs.io/en/latest/index.html)
* [Official Discord Server](https://dsc.gg/diskord-dev)
* [Discord API](https://discord.gg/discord-api)
* [Developer Portal](https://developer.discord.com/applications)
